<?php
session_start();

// 检查是否提供了长网址和 Turnstile 响应
if (!isset($_POST['long_url']) || empty($_POST['long_url']) ||
    !isset($_POST['cf-turnstile-response']) || empty($_POST['cf-turnstile-response'])) {
    die('请提供一个有效的长网址和验证码。');
}

$long_url = $_POST['long_url'];
$turnstile_response = $_POST['cf-turnstile-response'];

// 验证 Turnstile
$secret_key = '替换为你从 Cloudflare 获得的 Secret Key'; // 替换为你从 Cloudflare 获得的 Secret Key
$verify_url = 'https://challenges.cloudflare.com/turnstile/v0/siteverify';
$ch = curl_init();
curl_setopt($ch, CURLOPT_URL, $verify_url);
curl_setopt($ch, CURLOPT_POST, true);
curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query([
    'secret' => $secret_key,
    'response' => $turnstile_response,
]));
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
$response = curl_exec($ch);
curl_close($ch);

$response_keys = json_decode($response, true);

// 输出详细的错误信息
if (!$response_keys['success']) {
    $error_message = '<p>验证码验证失败，请重试。</p>';
    $error_details = '<pre>' . print_r($response_keys, true) . '</pre>';
    $html_error_content = <<<HTML
<!DOCTYPE html>
<html lang="zh">
<head>
    <meta charset="UTF-8">
    <title>验证失败</title>
</head>
<body>
    $error_message
    $error_details
</body>
</html>
HTML;
    echo $html_error_content;
    exit;
}

// 验证通过后，生成短网址
$short_code = generateUniqueShortCode();

// 确保 a 目录存在
$redirect_dir = __DIR__ . '/a';
if (!is_dir($redirect_dir)) {
    mkdir($redirect_dir, 0755, true);
}

// 创建一个新的目录以存储 index.html
$new_directory = $redirect_dir . "/$short_code";
if (!is_dir($new_directory)) {
    mkdir($new_directory, 0755, true);
}

// 创建一个静态HTML文件，文件名为 index.html
$redirect_file = $new_directory . "/index.html";
$redirect_content = "<!DOCTYPE html>
<html lang=\"zh\">
<head>
    <meta charset=\"UTF-8\">
    <meta http-equiv=\"refresh\" content=\"0; url=$long_url\">
    <title>重定向中...</title>
</head>
<body>
    如果您没有被自动重定向，请<a href=\"$long_url\">点击这里</a>。
</body>
</html>";

// 写入文件
file_put_contents($redirect_file, $redirect_content);

$protocol = isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? 'https' : 'http';

// 获取服务器名称（域名或 IP 地址）
$host = $_SERVER['HTTP_HOST'];

// 拼接主机名
$current_host = $protocol . '://' . $host;

$short_url = "$current_host/a/$short_code/";

$LOC_short_url = "[audio]$current_host/a/$short_code/[/audio]";

$Markdown_short_url = "[$current_host/a/$short_code/]($current_host/a/$short_code/)";

$html_content = <<<HTML
<!DOCTYPE html>
<html lang="zh">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>短网址生成成功</title>
</head>
<body>
    <p>短网址为: <br>
    <span id='shortUrl'>$short_url</span>&nbsp;<button onclick="copyToClipboard('shortUrl')">复制短网址</button></p>
    
        <p>LOC 发链接格式为: <br>
    <span id='LOCshortUrl'>$LOC_short_url</span>&nbsp;<button onclick="copyToClipboard('LOCshortUrl')">复制 LOC 链接格式</button></p>
    
    <p>Markdown 链接格式为: <br>
    <span id='MarkdownshortUrl'>$Markdown_short_url</span>&nbsp;<button onclick="copyToClipboard('MarkdownshortUrl')">复制 Markdown 链接格式</button></p>

<script>
    function copyToClipboard(id) {
        var urlElement = document.getElementById(id);
        if (urlElement) {
            var url = urlElement.innerText;
            navigator.clipboard.writeText(url).then(function() {
                alert(id + ' 已复制到剪贴板!');
            }, function(err) {
                alert('复制失败，请手动复制 ' + id + '。');
            });
        } else {
            alert('未找到元素: ' + id);
        }
    }
</script>





</body>
</html>
HTML;

echo $html_content;

/**
 * 生成唯一的短代码
 *
 * @param int $length 短代码的长度
 * @return string
 */
function generateUniqueShortCode($length = 6) {
    do {
        $short_code = generateShortCode($length);
    } while (is_dir(__DIR__ . "/a/$short_code"));
    return $short_code;
}

/**
 * 生成随机短代码
 *
 * @param int $length 短代码的长度
 * @return string
 */
function generateShortCode($length = 6) {
    $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
    $charactersLength = strlen($characters);
    $short_code = '';
    for ($i = 0; $i < $length; $i++) {
        $short_code .= $characters[rand(0, $charactersLength - 1)];
    }
    return $short_code;
}
?>
